<?php
if ( ! class_exists ( 'WP_List_Table' ) ) {
    require_once ( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class rpadts_Payment_List_Table extends WP_List_Table {

    function __construct() {
        
        global $status, $page;

        parent::__construct ( array (
            'singular' => 'subscriber', //singular name of the listed records
            'plural' => 'subscriber', //plural name of the listed records
            'ajax' => false        //does this table support ajax?
        ) );
        
    }

    function column_default ( $item, $column_name ) {
        
        date_default_timezone_set ( 'Asia/Calcutta' );
        
        switch($column_name){
            case 'name':
		return $item['first_name'] . " " . $item['last_name'];
            case 'payment_id':
                return  $item['payment_id'];
			case 'phone_number':
                return  $item['phone_number'];
			case 'address':
                return $item['address'].", ".$item['city']."- ".$item['zipcode'].", ".$item['state'].", ".$item['country'];
            case 'amount':
                return  $item['amount'];
			case 'donation_type':
                return  $item['donation_type'];
            case 'created_at':
                return  $item['created_at'];
            default:
                return print_r($item,true); //Show the whole array for troubleshooting purposes
        }
        
    }

    function column_title( $item ) {

        //Build row actions
        $actions = array(
            'edit' => sprintf ( '<a href="?page=%s&action=%s&subscriber=%s"> Edit </a>', $_REQUEST['page'], 'edit', $item['id']),
            'delete' => sprintf ( '<a href="?page=%s&action=%s&subscriber=%s"> Delete </a>', $_REQUEST['page'], 'delete', $item['id'] ),
        );

        //Return the title contents
        return sprintf ( '%1$s <span style="color:silver"> (id:%2$s) </span> %3$s',
                $item['name'],
                $item['id'],
                $this->row_actions ( $actions )
        );
        
    }
    
    function column_cb( $item ){
        
        return sprintf (
            '<input type="checkbox" name="%1$s[]" value="%2$s" />',
            $this->_args [ 'singular' ],  
            $item['id']   //The value of the checkbox should be the record's id
        );
        
    }

    function get_columns() {
        
        $columns = array (
            'cb' => '<input type="checkbox" />', //Render a checkbox instead of text
            'name' => 'Name',
            'payment_id' => 'Payment ID',
			'phone_number' => 'Mobile Number',
			'address' => 'Address',
            'amount' => 'Amount',
			'donation_type' => 'Payment Type',
            'created_at' => 'Created at'
        );
        
        return $columns;
        
    }

    function get_sortable_columns() {
        
        $sortable_columns = array (
            'name' => array ( 'first_name', false) , array ( 'last_name', false),  //true means it's already sorted
            'created_at' => array ( 'created_at', false )
        );
        
        return $sortable_columns;
        
    }

    function get_bulk_actions() {
        
        $actions = array (
            'delete' => 'Delete'
        );
        
        return $actions;
        
    }

    function process_bulk_action() {
        
        global $wpdb;
        $table_transaction = $wpdb->prefix . 'stripe_transaction_table';
        if ( 'delete' === $this->current_action() ) {
            $ids = isset ( $_REQUEST['subscriber'] ) ? $_REQUEST['subscriber'] : array();
            $id = implode ( ',', $ids );
            if ( !empty ( $id ) ) {
                $wpdb->query ( "DELETE FROM $table_transaction WHERE id IN ( $id ) " );
            }
        }
        
    }

    function prepare_items() {
        
        global $wpdb;
        $table_transaction = $wpdb->prefix . 'stripe_transaction_table'; // do not forget about tables prefix

        $per_page = 20; // constant, how much records will be shown per page

        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        // here we configure table headers, defined in our methods
        $this->_column_headers = array($columns, $hidden, $sortable);

        // [OPTIONAL] process bulk action if any
        $this->process_bulk_action();

        // prepare query params, as usual current page, order by and order direction
        $do_search = '';
        $name = ( isset( $_REQUEST['search_name'] ) ) ? sanitize_text_field( $_REQUEST['search_name'] ) : false;
        $payment_id = ( isset( $_REQUEST['search_payment_id'] ) ) ? sanitize_text_field( $_REQUEST['search_payment_id'] ) : false;
        
		if($name !="")
		{
		$name = explode(' ',$name);
		
		
		$fname = $name[0];
		$lname = $name[1];
		
		
        $do_search  = ( $fname ) ? $wpdb->prepare(" AND first_name = '%s' ", $fname ) : '';
		$do_search .= ( $lname ) ? $wpdb->prepare(" AND last_name = '%s' ", $lname ) : '';
		}
        $do_search .= ( $payment_id ) ? $wpdb->prepare(" AND payment_id = '%s' ", $payment_id ) : '';

        $paged = isset ( $_REQUEST['paged']) ? max ( 0, intval ( $_REQUEST['paged'] ) - 1) : 0;
        $offset = $paged * $per_page;
        $orderby = ( isset ( $_REQUEST['orderby'] ) && in_array ( $_REQUEST['orderby'], array_keys ( $this->get_sortable_columns()))) ? $_REQUEST['orderby'] : 'created_at';
        $order = ( isset ( $_REQUEST['order'] ) && in_array($_REQUEST['order'], array('asc', 'desc'))) ? $_REQUEST['order'] : 'desc';

        $this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_transaction WHERE payment_status = 'succeeded' $do_search ORDER BY $orderby $order LIMIT %d OFFSET %d", $per_page, $offset), ARRAY_A);
		
		if(!empty($name) || !empty($payment_id)) {
			// will be used in pagination settings
			$total_items = count($this->items);
		} else {
			// will be used in pagination settings
			$total_items = $wpdb->get_var ( "SELECT COUNT(id) FROM $table_transaction " );
		}
        // [REQUIRED] configure pagination
        $this->set_pagination_args ( array(
            'total_items' => $total_items, // total items defined above
            'per_page' => $per_page, // per page constant defined at top of method
            'total_pages' => ceil ( $total_items / $per_page) // calculate pages count
        ) );
    }

}

function rpadts_payments() {
    $rpadtsListTable = new rpadts_Payment_List_Table();

    $rpadtsListTable->prepare_items();
    ?>
	<div class="wrap">

        <div id="icon-users" class="icon32"> <br/> </div>
        
        <h2> <?php _e ( 'Stripe Payments ', 'rpadts' ); ?> </h2>
        <?php
            $s_name = ( isset( $_REQUEST['search_name'] ) ) ? $_REQUEST['search_name'] : false;
            $s_payment_id = ( isset( $_REQUEST['search_payment_id'] ) ) ? $_REQUEST['search_payment_id'] : false;
        ?>
        <!-- Forms are NOT created automatically, so you need to wrap the table in one to use features like bulk actions -->

        <form id="subscribers-filter" method="get">
            <!-- For plugins, we also need to ensure that the form posts back to our current page -->
            <input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
            <!-- Now we can render the completed list table -->
            
            <input type="text" name="search_name" id="search_name" value="<?php echo $s_name; ?>" placeholder="Name"/>
            <input type="text" name="search_payment_id" id="search_payment_id" value="<?php echo $s_payment_id; ?>" placeholder="Payment ID"/>
            
            <input type="submit" name="search-submit" id="search-submit" class="button" value="Search">
            <?php $rpadtsListTable->display() ?>
        </form>

    </div>
    <?php
}