<?php
/*
  Plugin Name: Recurring Payment & Donation Through Stripe
  Plugin URI:  http://brainvire.com/
  Description: Recurring Payment & Donation Through Stripe
  Version: 1.0
  Author: Brainvireinfo
  Author URI: https://www.brainvire.com/
  License: GPL2
 */

if ( !defined( 'ABSPATH' ) )
    exit;

	
if ( ! defined( 'RPADTS_NAME' ) ) {
	define( 'RPADTS_NAME', trim( dirname( plugin_basename( __FILE__ ) ), '/' ) );
}

if ( ! defined( 'RPADTS_BASENAME' ) ) {
	define( 'RPADTS_BASENAME', plugin_basename( __FILE__ ) );
}

if ( ! defined( 'RPADTS_DIR' ) ) {
	define( 'RPADTS_DIR', plugin_dir_path( __FILE__ ) );
}

//Stripe PHP library
require_once( dirname( __FILE__ ) . '/vendor/stripe/stripe-php/init.php' );
if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'test' ) {
	\Stripe\Stripe::setApiKey(esc_attr(get_option('rpadts_secretKey_test')));
} else if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'live' ){
	\Stripe\Stripe::setApiKey(esc_attr(get_option( 'rpadts_secretKey_live')));
}

include_once RPADTS_DIR . '/admin/rpadts-setting-page.php';
include_once RPADTS_DIR . '/admin/rpadts-currency.php';
include_once RPADTS_DIR . '/admin/rpadts-help-page.php';
include_once RPADTS_DIR . '/admin/rpadts-payment-page.php';


function rpadts_enqueue_scripts() {  
    
wp_register_style( 'rpadts-main-css', plugins_url( '/assets/css/newstyle.css', __FILE__ ) );
wp_enqueue_style( 'rpadts-main-css' );

wp_register_script( 'rpadts-checkout-form', plugins_url( '/assets/js/rpadts-checkout-form.js', __FILE__ ), array(), '', 1 );
wp_enqueue_script('rpadts-checkout-form');

wp_register_script( 'rpadts-jquery-validate', plugins_url( '/assets/js/jquery.validate.js', __FILE__ ), array(), '', 1 );
wp_enqueue_script( 'rpadts-jquery-validate' );

wp_enqueue_script( 'jquery' );
wp_enqueue_script( 'jquery-ui-datepicker', array( 'jquery' ) );


wp_register_style('rpadts-jquery-ui', plugins_url( '/assets/css/jquery-ui.css', __FILE__ ));
wp_enqueue_style( 'rpadts-jquery-ui' );    


}
add_action( 'wp_enqueue_scripts', 'rpadts_enqueue_scripts' );


function rpadts_admin_enqueue_scripts() 
{
    wp_register_style( 'rpadts-css-main', plugins_url( '/assets/css/main.css', __FILE__ ) );
    wp_enqueue_style( 'rpadts-css-main' );
    wp_enqueue_style( 'thickbox' );
    
    wp_enqueue_script( 'jquery-ui-datepicker' );
    wp_enqueue_script( 'media-upload' );
	
	wp_enqueue_script( 'rpadts-admin-validation',plugins_url( '/assets/js/rpadts-admin-validation.js', __FILE__ ), 'jquery' );
    
    wp_enqueue_media();
    
}
add_action( 'admin_enqueue_scripts', 'rpadts_admin_enqueue_scripts' );



/*
 *  Auto-Create table while active plugin
 */
function rpadts_custom_plugin_activation() {
    
    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    global $wpdb;
    $stripe_transaction_table = $wpdb->prefix . 'stripe_transaction_table';

    if ( $wpdb->get_var( "SHOW TABLES LIKE '$stripe_transaction_table'" ) != $stripe_transaction_table ) {
        
        if ( !empty( $wpdb->charset ) )
            $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
        
        if ( !empty( $wpdb->collate ) )
            $charset_collate .= " COLLATE $wpdb->collate";

        $sql_rp = 	"CREATE TABLE " . $stripe_transaction_table . " (
                         id int(10) unsigned NOT NULL AUTO_INCREMENT,
                         first_name varchar(256) NOT NULL,
                         last_name varchar(256) NOT NULL,
                         email varchar(256) NOT NULL,
						 phone_number varchar(256) NOT NULL,
						 address text NOT NULL,
						 country text NOT NULL,
						 state text NOT NULL,
						 city text NOT NULL,
						 zipcode varchar(256) NOT NULL,
						 amount varchar(256) NOT NULL,
						 donation_type varchar(256) NOT NULL,
						 period_start varchar(256) NOT NULL,
						 period_end varchar(256) NOT NULL,
						 payment_currency varchar(256) NOT NULL,
                         payment_id varchar(256) NOT NULL,
                         payment_status varchar(256) NOT NULL,
                         created_at varchar(256) NOT NULL,
					PRIMARY KEY (id)
			 )		$charset_collate;";
			 
			dbDelta($sql_rp);
    }
    
    $user_id = get_current_user_id();
    
    if ( get_page_by_title( 'Stripe Thank you!' ) == NULL ) {
        $thankyou_post = array(
            'comment_status' => 'closed',
            'ping_status' => 'closed',
            'post_author' => $user_id,
            'post_name' => 'stripe-thank-you',
            'post_status' => 'publish',
            'post_title' => 'Stripe Thank you!',
            'post_content' => '',
            'post_type' => 'page',
        );
        //insert page and save the id
        $thankyou_page = wp_insert_post( $thankyou_post );
    }

    update_option( 'rpadts_apiMode', 'test' );
    update_option( 'rpadts_currency', 'usd' );
    update_option( 'rpadts_email_subject', 'Payment Receipt' );
    update_option( 'rpadts_email_messagebody', '<html><body><p>Hi %FIRSTNAME% %LASTNAME%,</p><p>Thanks for your payment/donation. Here your receipt for your payment.</p><p>%FIRSTNAME% - %LASTNAME%</p><p>%ADDRESS%</p><p>%CITY%, %STATE%</p><p>%COUNTRY% - %ZIP%</p><br/><p>Payment Mode:</p><p>Donation Amount: %AMOUNT% </p><p>Donation frequency: %DONATIONTYPE%</p><p>Date of Donation: %PAYMENTDATE%</p><br/>
	<p>Sincerely,</p><p>%SITENAME%</p><body></html>' );
}
register_activation_hook( __FILE__, 'rpadts_custom_plugin_activation' );


function rpadts_menu_pages() 
{
    // Add the top-level admin menu
    $page_title = 'Recurring P&D Through Stripe Setting';
    $menu_title = 'Recurring P&D Through Stripe';
    $menu_slug  = 'rpadts-settings';
    $capability = 'manage_options';
    $function   = 'rpadts_settings_callback';
    add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function );

    // Add submenu page with same slug as parent to ensure no duplicates
    $sub_menu_title = 'Settings';
    add_submenu_page( $menu_slug, $page_title, $sub_menu_title, $capability, $menu_slug, $function );

    $submenu_page_title = 'Stripe Payments';
    $submenu_title      = 'Payments';
    $submenu_slug       = 'stripe-payments';
    $submenu_function   = 'rpadts_payments';
    add_submenu_page( $menu_slug, $submenu_page_title, $submenu_title, $capability, $submenu_slug, $submenu_function );
    
    $submenu_page_title = 'Help';
    $submenu_title      = 'Help';
    $submenu_slug       = 'rpadts-help';
    $submenu_function   = 'rpadts_help';
    add_submenu_page( $menu_slug, $submenu_page_title, $submenu_title, $capability, $submenu_slug, $submenu_function );
}
add_action( 'admin_menu', 'rpadts_menu_pages' );


/*
 * Checkout Page Function
 */
function rpadts_checkout_page_callback() 
{
	date_default_timezone_set ( 'Asia/Calcutta' );
    if(!empty($_POST['stripeToken']) && !empty($_POST['amount']))
    {
        $errors = array();
        global $wpdb;

	$fname = !empty($_POST['fname']) ? sanitize_text_field($_POST['fname']) : '';
	$lname = !empty($_POST['lname']) ? sanitize_text_field($_POST['lname']) : '';
	$email = !empty($_POST['email']) ? sanitize_email($_POST['email']) : '';
	$phone = !empty($_POST['phone_no']) ? sanitize_text_field($_POST['phone_no']) : '';
	$address = !empty($_POST['address']) ? sanitize_text_field($_POST['address']) : '';
	$country = !empty($_POST['country']) ? sanitize_text_field($_POST['country']) : '';
	$state = !empty($_POST['state']) ? sanitize_text_field($_POST['state']) : '';
	$city = !empty($_POST['city']) ? sanitize_text_field($_POST['city']) : '';
	$zipcode = !empty($_POST['zipcode']) ? sanitize_text_field($_POST['zipcode']) : '';
	$amount = !empty($_POST['amount']) ? absint($_POST['amount']) : '';
	$payment_type = !empty($_POST['payment_type_radio']) ? sanitize_text_field($_POST['payment_type_radio']) : '';
	$payment_interval = !empty($_POST['recurringInterval']) ? sanitize_text_field($_POST['recurringInterval']) : '';
	$created_at = strtotime( date( 'Y-m-d H:i:s' ) );
	$end_date_recurring = !empty($_POST['end_date_recurring']) ? sanitize_text_field($_POST['end_date_recurring']) : '';
	$end_date_rec = strtotime($end_date_recurring);
	
	
	$created = gmdate("Y-m-d H:i:s", $period_start);
	
	$token  = $_POST['stripeToken'];
	$amt = $amount * 100;
	
	$full_name = $fname.' '.$lname;
	
	$description = 'Payment from ' .$full_name. ' :';
	
	$metadata = array(
				'customer_name'           => $full_name,
				'customer_email'          => $email,
				'customer_phone'          => $phone,
				'billing_address_line'    => $address,
				'billing_address_country' => $country,
				'billing_address_state'    => $state,
				'billing_address_city'    => $city,
				'billing_address_zip'     => $zipcode,
			);  
        
        $random_id =  rpadts_random_string( 
                                        array(
                                                'characters'  =>  'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789',
                                                'length'      =>  14
                                                ) 
                                        );
	if($_POST['recurringInterval'] == '1time' || esc_attr(get_option( 'rpadts_recurring_payment_check' ) ) != 1) 
        {
			try 
			{
				$customer = \Stripe\Customer::create(array(
				  'email' => $email,
				  'card'  => $token,
				  'metadata' => $metadata,
				));
			
				 $charge = \Stripe\Charge::create(array(
				  'customer' => $customer->id,
				  'amount'   => $amt,
				  'currency' => get_option( 'rpadts_currency' ),
				  'description' => $description,
				  'metadata' => $metadata,
				));
			
				$payment_id = $charge->id;
						$payment_status = $charge->status;
						$payment_amount = $charge->amount;
						$payment_amount = $payment_amount/100;
						$payment_freqency = "One Time Payment";
						
						foreach ( rpadts_currencies() as $currency_key => $currency_obj ) 
						{
							if ( esc_attr(get_option( 'rpadts_currency' )) === $currency_key ) {
									$currency_sign .= $currency_obj['symbol'];
							}
						}
						
						$payment_amt = $currency_sign.''.$payment_amount;
						
						rpadts_send_payment_email_receipt($email, $created, $address, $city, $state, $country, $zipcode, '', '', $payment_amt, $fname, $lname, site_url(), $payment_freqency);
						  
						if($charge->status == 'succeeded') {
							rpadts_stripe_create_order($fname, $lname, $email, $phone, $address, $country, $state, $city, $zipcode, $payment_amount, $payment_freqency, '', '', get_option( 'rpadts_currency' ), $payment_id, $payment_status, $created_at );
						}
					
						unset( $_POST['stripeToken'] );
							
						//session
						session_start();
						$_SESSION['confirmation_msg'] = $payment_id;
						$_SESSION['confirmation_full_name'] = $full_name;
						$_SESSION['confirmation_email'] = $email;
						wp_redirect(home_url('stripe-thank-you'));
						exit;
			} 	
			catch ( \Stripe\Error\Card $e ) 
			{
				$errors['stripe'] = array(
					'success' => false,
					'ex_msg'  => $e->getMessage()
				);
			} 
			catch ( Exception $e ) 
			{
				//show notification of error
				$errors['stripe'] = array(
					'success' => false,
					'ex_msg'  => $e->getMessage()
				);
			}
        }
        if(sanitize_text_field($_POST['recurringInterval']) == '1m' || sanitize_text_field($_POST['recurringInterval']) == '3m' || sanitize_text_field($_POST['recurringInterval']) == '6m' || sanitize_text_field($_POST['recurringInterval']) == '12m')
        {
		
				if($payment_interval == '1m') {
					$int_count = 1;
					$payment_level = 'month';
					$payment_interval = 'month';
					$payment_freq = 'Monthly';
				}
				if($payment_interval == '3m') {
					$payment_interval = '3-month';
					$int_count = explode('-', $payment_interval);
					$int_count = $int_count[0];
					$payment_level = 'month';
					$payment_interval = '3-month';
					$payment_freq = 'Quarterly';
				}
				if($payment_interval == '6m') {
					$payment_interval = '6-month';
					$int_count = explode('-', $payment_interval);
					$int_count = $int_count[0];
					$payment_level = 'month';
					$payment_interval = 'Half-a-Year';
					$payment_freq = '6-month';
				}
				if($payment_interval == '12m') {
					$int_count = 1;
					$payment_level = 'year';
					$payment_interval = 'year';
					$payment_freq = 'Annually';
				}
				
			try 
			{
				$customer = \Stripe\Customer::create(array(
							'email' => $email,
							'card'  => $token,
							'metadata' => $metadata,
					));
					
					$plan = \Stripe\Plan::create(array(
						  "name" => $payment_interval.'-'.$random_id,
						  "id" => $payment_interval.'-'.$random_id,
						  "interval" => $payment_level,
						  "interval_count" => $int_count,
						  "currency" => esc_attr(get_option( 'rpadts_currency' )),
						  "amount" => $amt,
						  "metadata"       => $metadata
					));
					
				
			$subscription = \Stripe\Subscription::create(array(
			  "customer" => $customer->id,
			  "plan" => $payment_interval.'-'.$random_id,
			));		

			$subscription_end = \Stripe\Subscription::retrieve($subscription->id);
			$subscription_end->trial_end = $end_date_rec;
			$subscription_end->prorate = false;
			$subscription_end->save();
			
			$charge = \Stripe\Charge::all(array("limit" => 1));
								
			foreach ($charge->data as $charges) {
			$payment_id = $charges->id;
			$payment_status = $charges->status;
			$payment_amount = $charges->amount;
			$payment_amount = $payment_amount/100; 
			}
			
			$get_invoice = \Stripe\Invoice::upcoming(array("customer" => $customer->id));
			$period_end = $get_invoice->period_end;
			$period_start = $get_invoice->period_start;
			$payment_freqency = 'Recurring Payment - '.$payment_freq;
			
			foreach ( rpadts_currencies() as $currency_key => $currency_obj ) 
			{
				if ( esc_attr(get_option( 'rpadts_currency' )) === $currency_key ) {
						$currency_sign .= $currency_obj['symbol'];
				}
			}
			
			$payment_amt = $currency_sign.''.$payment_amount;
			
					if(!empty($payment_amount)) 
					{
						rpadts_send_payment_email_receipt($email, $created, $address, $city, $state, $country, $zipcode, gmdate("Y-m-d", $period_start), gmdate("Y-m-d", $period_end), $payment_amt, $fname, $lname, site_url(), $payment_freqency);
					}
					
					if($charges->status == 'succeeded') {
						rpadts_stripe_create_order($fname, $lname, $email, $phone, $address, $country, $state, $city, $zipcode, $payment_amount, $payment_freqency, gmdate("Y-m-d", $period_start), gmdate("Y-m-d", $period_end), get_option( 'rpadts_currency' ), $payment_id, $payment_status, $created_at );
					}
					
			unset( $_POST['stripeToken'] );
			//session
			session_start();
					$_SESSION['confirmation_msg'] = $payment_id;
					$_SESSION['confirmation_full_name'] = $full_name;
					$_SESSION['confirmation_email'] = $email;

					wp_redirect(home_url('stripe-thank-you'));
					exit;
			}
			catch ( \Stripe\Error\Card $e ) 
			{
				$errors['stripe'] = array(
					'success' => false,
					'ex_msg'  => $e->getMessage()
				);
			} 
			catch ( Exception $e ) 
			{
				$errors['stripe'] = array(
					'success' => false,
					'ex_msg'  => $e->getMessage()
				);
			}
			
			 
        }
		
  }
  ?>
	<script type="text/javascript">
		<?php if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'test' ) { ?>
			Stripe.setPublishableKey('<?php esc_attr(get_option('rpadts_secretKey_test')); ?>');
		<?php } else if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'live' ){ ?>
			Stripe.setPublishableKey('<?php esc_attr(get_option( 'rpadts_secretKey_live')); ?>');
		<?php } ?>
	</script>
  <?php
  
  $fname_var = !empty($_POST['fname']) ? sanitize_text_field($_POST['fname']) : '';
  $lname_var = !empty($_POST['lname']) ? sanitize_text_field($_POST['lname']) : '';
  $email_var = !empty($_POST['email']) ? sanitize_email($_POST['email']) : '';
  $phone_no_var = !empty($_POST['phone_no']) ? sanitize_text_field($_POST['phone_no']) : '';
  $address_var = !empty($_POST['address']) ? sanitize_text_field($_POST['address']) : '';
  $city_var = !empty($_POST['city']) ? sanitize_text_field($_POST['city']) : '';
  $state_var = !empty($_POST['state']) ? sanitize_text_field($_POST['state']) : '';
  $country_var = !empty($_POST['country']) ? sanitize_text_field($_POST['country']) : '';
  $zipcode_var = !empty($_POST['zipcode']) ? sanitize_text_field($_POST['zipcode']) : '';
  $amount_var = !empty($_POST['amount']) ? absint($_POST['amount']) : '';
  
  if( !empty(get_option('rpadts_currency')) ){
			
			$rpadts_currency = get_option( 'rpadts_currency' ); 
  }	  
  
	if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'test' ) 
	{
		$publish_stripe_key = esc_attr( get_option( 'rpadts_publishKey_test' ) );
	} 
	else if( esc_attr( get_option( 'rpadts_apiMode' ) ) == 'live' )
	{
		$publish_stripe_key = esc_attr( get_option( 'rpadts_publishKey_live' ) );
	}
  
		$html = "";
        $html .='<form action="" method="POST" class="form-horizontal stripe-payment-frm" id="stripe-payment-frm">';
        $html .='<fieldset>';
			// Show PHP errors, if they exist:
			if (isset($errors) && !empty($errors) && is_array($errors)) {
				foreach ($errors as $e) {
					$html .='<p class="alert alert-error">"'.$e['ex_msg'].'"</p>';
				} 
			}
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">First Name<span style="color:red;">*</span></label>';
                $html .='<div class="controls">';
                    $html .='<input type="text" class="fullstripe-form-input" name="fname" id="" value="'.$fname_var.'">';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Last Name<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" class="fullstripe-form-input" name="lname" id="" value="'.$lname_var.'">';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Email<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="email" class="fullstripe-form-input" name="email" id="" value="'.$email_var.'">';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Phone Number<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" class="fullstripe-form-input" name="phone_no" id="" maxlength="13" value="'.$phone_no_var.'">';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Address/Street<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
					$html .='<textarea name="address" id="" class="fullstripe-form-input">'.$address_var.'</textarea><br>';
                $html .='</div>';
            $html .='</div>';
			$html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">City<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" name="city" id="" class="fullstripe-form-input" value="'.$city_var.'"><br>';
                $html .='</div>';
            $html .='</div>';
			$html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">State<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" name="state" id="" class="fullstripe-form-input" value="'.$state_var.'"><br>';
                $html .='</div>';
            $html .='</div>';
			$html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Country<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" name="country" id="" class="fullstripe-form-input" value="'.$country_var.'"><br>';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label">Zip<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" name="zipcode" id="" class="fullstripe-form-input" maxlength="10" value="'.$zipcode_var.'"><br>';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="control-group">';
                $html .='<label class="control-label fullstripe-form-label"> Amount ('.$rpadts_currency.')
				<span style="color:red;">*</span></label>';

                $html .='<div class="controls">';
                    $html .='<input type="text" name="amount" id="" class="fullstripe-form-input" maxlength="10" 
					value="'.$amount_var.'" placeholder=""><br>';
                $html .='</div>';
            $html .='</div>';
			if( esc_attr( get_option( 'rpadts_recurring_payment_check' ) ) == 1 ) {
            $html .='<div class="control-group recurring">';
                $html .='<label class="control-label fullstripe-form-label" for="stripe-recurring-sec">Payment Mode</label>';
                $html .='<div class="controls">';
                    $html .='<select name="recurringInterval" class="neon2Field2" onchange="rpadts_show_datepicker(this.value);">';
                        $html .='<option value="1time">One Time</option>';
						$html .='<option value="1m">Monthly</option>';
                        $html .='<option value="3m">Quarterly</option>';
                        $html .='<option value="6m">Semi-Annually</option>';
                        $html .='<option value="12m">Annually</option>';
                    $html .='</select>';
                $html .='</div>';
            $html .='</div>';
             }  else  {
				$html .='<input type="hidden" name="payment_type_radio" id="" value="one_time_payment">';
			 }  
			$html .='<div class="control-group" id="recurringEndDate" style="display:none;">';
                $html .='<label class="control-label fullstripe-form-label">End Date</label>';
				$html .='<div class="controls">';
				$html .='<div class="">';
					$html .='<input type="text" name="end_date_recurring" class="form-control" id="recurring_end_date" readonly="">';
				$html .='</div>';
				$html .='</div>';
				
            $html .='</div>';
			
			
            $html .='<div class="control-group">';
                $html .='<div class="controls">';
                    $html .='<button id="" class="tsttt make_payment_btn" name="submit_form">Make Payment</button>';
                $html .='</div>';
            $html .='</div>';
            $html .='<div class="stripe_popup" style="display: none;">'; 
                    $html .='<script type="text/javascript" src="https://js.stripe.com/v2/"></script>';
                    
                    $html .= '<script src="https://checkout.stripe.com/checkout.js" class="stripe-button" data-key="'.$publish_stripe_key.'" data-amount="" data-name="'.get_option('rpadts_popup_name').'" data-description="'.esc_attr(get_option('rpadts_popup_desc')).'" data-image="'.esc_attr(get_option('stripe_custom_logo')).'" data-locale="auto"></script>';
                  $html .='</div>';
        $html .='</fieldset>';
    $html .='</form>';
	return $html;
}
add_shortcode( 'stripe-checkout-page', 'rpadts_checkout_page_callback' );





/*
 * Insert data taransaction table in database
 */
function rpadts_stripe_create_order($fname, $lname, $email, $phone, $address, $country, $state, $city, $zipcode, $amount, $payment_type, $period_start, $period_end, $payment_currency, $payment_id, $payment_status, $created_at ) {
    
    global $wpdb;
    date_default_timezone_set('Asia/Calcutta');
                
        $insert = $wpdb->insert( 
				$wpdb->prefix .'stripe_transaction_table', 
				array( 
					'first_name'        => $fname,
					'last_name'         => $lname,
					'email'    			=> $email,
					'phone_number'      => $phone,
					'address'    		=> $address,
					'country'    		=> $country,
					'state'    			=> $state,
					'city'    			=> $city,
					'zipcode'    		=> $zipcode,
					'amount'    		=> $amount,
					'donation_type'    	=> $payment_type,
					'period_start'    	=> $period_start,
					'period_end'    	=> $period_end,
					'payment_currency'  => $payment_currency,
					'payment_id'    	=> $payment_id,
					'payment_status'    => $payment_status,
					'created_at'    	=> date('Y-m-d H:i:s', $created_at)
				), 
				array(  
					'%s', 
					'%s', 
					'%s',
					'%s', 
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',
					'%s',					
					'%s',
					'%s', 
					'%s', 
					'%s',
					'%s',
					'%s'
				) 
			);
        
        if( $insert ) {
            $wpdb->insert_id;
        }
        else {
            return false;
        }
}


function rpadts_page_template_redirect()
{
	//session
	ob_start();
	session_start();
	
    if( is_page( 'stripe-thank-you' ) && !empty($_SESSION['confirmation_msg']))
    {
        add_filter('the_content','rpadts_thankyou_page_content');
    }
}
add_action( 'template_redirect', 'rpadts_page_template_redirect' );
function rpadts_thankyou_page_content($content)
{
	
    $success = '';
  $get_trans = $_SESSION['confirmation_msg'];
  $get_full_name = $_SESSION['confirmation_full_name'];
  $get_email = $_SESSION['confirmation_email'];
        
			$success .= '<div class="container">';
            $success .= '<h4 class="greencolor"><strong>Dear '. $get_full_name .'</strong></h4><h5>Your payment has been processed successfully.</h5><p>Your payment ID - '. $get_trans .'</p>';
            $success .= '<p>We have sent your receipt to your email id which is used for payment - '. $get_email .'</p></br></div>';
			
		unset($_SESSION["confirmation_msg"]);
		unset($_SESSION["confirmation_full_name"]);
		unset($_SESSION["confirmation_email"]);
		ob_flush();
    return $success;
}


/*
 * Generate random string
 */
function rpadts_random_string($args = array()){
	$random_string = '';
    $defaults = array(  // Set some defaults for the function to use
        'characters'    => '',
        'length'        => '',
        'before'        => '',
        'after'         => '',
        'echo'          => false
    );
    $args = wp_parse_args($args, $defaults);    // Parse the args passed by the user with the defualts to generate a final '$args' array

    if(absint($args['length']) < 1) // Ensure that the length is valid
        return;

    $characters_count = strlen($args['characters']);    // Check how many characters the random string is to be assembled from
    for($i = 0; $i <= $args['length']; $i++) :          // Generate a random character for each of '$args['length']'

        $start = mt_rand(0, $characters_count);
        $random_string.= substr($args['characters'], $start, 1);

    endfor;

    $random_string = $args['before'] . $random_string . $args['after']; // Add the before and after strings to the random string

    if($args['echo']) : // Check if the random string shoule be output or returned
        echo $random_string;
    else :
        return $random_string;
    endif;

}


function rpadts_send_payment_email_receipt($user_email, $payment_date, $address, $city, $state, $country, $zipcode, $recurring_payment_start, $recurring_payment_end, $amount, $fname, $lname, $sitename, $donation_type) {
    
    $set_from = ( esc_attr( get_option( 'rpadts_email_receipt_sender_address' ) ) ? esc_attr( get_option( 'rpadts_email_receipt_sender_address' ) ) : get_option( 'admin_email' ) );
    $set_cc = ( esc_attr( get_option( 'rpadts_cc_payment_receipt' ) ) ? esc_attr( get_option( 'rpadts_cc_payment_receipt' ) ) : get_option( 'admin_email' ) );
    $to = $user_email;
    $subject = esc_attr( get_option( 'rpadts_email_subject' ) );
    $msg_body = get_option( 'rpadts_email_messagebody' );
    $rep_keyword = array( "%CUSTOMER_EMAIL%", "%PAYMENTDATE%", "%ADDRESS%", "%CITY%", "%STATE%", "%COUNTRY%", "%ZIP%", "%RECURRING_PAYMENT_START%", "%RECURRING_PAYMENT_END%", "%AMOUNT%", "%FIRSTNAME%", "%LASTNAME%", "%SITENAME%", "%DONATIONTYPE%" );
    $rep_value = array( $user_email, $payment_date, $address, $city, $state, $country, $zipcode, $recurring_payment_start, $recurring_payment_end, $amount, $fname, $lname, $sitename, $donation_type );
    $body = str_replace( $rep_keyword, $rep_value, $msg_body );
    $site_url = get_bloginfo();
    
    $header = "From: $set_from \r\n";
    $header .= "Cc: $set_cc \r\n";
    $header .= "MIME-Version: 1.0\r\n";
    $header .= "Content-type: text/html\r\n";
    
    wp_mail( $to, $subject, $body, $header );
}